@@ -268,7 +268,7 @@ class ImageDrawExBase(base.ImageDraw):
         if maxwidth is None:
             maxwidth = 65535
 
-        box = (0, 0, maxwidth, 65535)
+        box = Box(0, 0, maxwidth, 65535)
         textbox = textfolder.get(self, box, string, font,
                                  scale=self.scale_ratio, **kwargs)
         return textbox.outlinebox.size
