@@ -6,6 +6,36 @@ from blockdiag.builder import *
 from blockdiag.parser import parse_string
 
 
+def supported_pil():
+    try:
+        import _imagingft
+        return True
+    except:
+        return False
+
+
+def with_pil(fn):
+    if not supported_pil():
+        fn.__test__ = False
+
+    return fn
+
+
+def supported_pdf():
+    try:
+        import reportlab
+        return True
+    except:
+        return False
+
+
+def with_pdf(fn):
+    if not supported_pdf():
+        fn.__test__ = False
+
+    return fn
+
+
 def argv_wrapper(func, argv=[]):
     def wrap(*args, **kwargs):
         try:
